==> phpMinAdmin-1.7.0.zip: phpMinAdmin-1.7.0/lang/nl.inc.php <==
<?php
$translations = array(
	'Login' => 'Inloggen',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => 'Uitloggen geslaagd.',
	'Invalid credentials.' => 'Ongeldige logingegevens.',
	'Server' => 'Server',
	'Username' => 'Gebruikersnaam',
	'Password' => 'Wachtwoord',
	'Select database' => 'Database selecteren',
	'Invalid database.' => 'Ongeldige database.',
	'Create new database' => 'Nieuwe database',
	'Table has been dropped.' => 'Tabel verwijderd.',
	'Table has been altered.' => 'Tabel aangepast.',
	'Table has been created.' => 'Tabel aangemaakt.',
	'Alter table' => 'Tabel aanpassen',
	'Create table' => 'Tabel aanmaken',
	'Table name' => 'Tabelnaam',
	'engine' => 'engine',
	'collation' => 'collation',
	'Column name' => 'Kolomnaam',
	'Type' => 'Type',
	'Length' => 'Lengte',
	'NULL' => 'NULL',
	'Auto Increment' => 'Auto nummering',
	'Options' => 'Opties',
	'Save' => 'Opslaan',
	'Drop' => 'Verwijderen',
	'Database has been dropped.' => 'Database verwijderd.',
	'Database has been created.' => 'Database aangemaakt.',
	'Database has been renamed.' => 'Database hernoemd.',
	'Database has been altered.' => 'Database aangepast.',
	'Alter database' => 'Database aanpassen',
	'Create database' => 'Database aanmaken',
	'SQL command' => 'SQL opdracht',
	'Dump' => 'Exporteer',
	'Logout' => 'Uitloggen',
	'database' => 'database',
	'Use' => 'Gebruik',
	'No tables.' => 'Geen tabellen.',
	'select' => 'kies',
	'Create new table' => 'Nieuwe tabel',
	'Item has been deleted.' => 'Item verwijderd.',
	'Item has been updated.' => 'Item aangepast.',
	'Item has been inserted.' => 'Item toegevoegd.',
	'Edit' => 'Bewerk',
	'Insert' => 'Toevoegen',
	'Save and insert next' => 'Opslaan, daarna toevoegen',
	'Delete' => 'Verwijderen',
	'Database' => 'Database',
	'Routines' => 'Procedures',
	'Indexes has been altered.' => 'Index aangepast.',
	'Indexes' => 'Indexen',
	'Alter indexes' => 'Indexen aanpassen',
	'Add next' => 'Volgende toevoegen',
	'Language' => 'Taal',
	'Select' => 'Kies',
	'New item' => 'Nieuw item',
	'Search' => 'Zoeken',
	'Sort' => 'Sorteren',
	'DESC' => 'Aflopend',
	'Limit' => 'Beperk',
	'No rows.' => 'Geen rijen.',
	'Action' => 'Acties',
	'edit' => 'bewerk',
	'Page' => 'Pagina',
	'Query executed OK, %d row(s) affected.' => array('Query uitgevoerd, %d rij geraakt.', 'Query uitgevoerd, %d rijen geraakt.'),
	'Error in query' => 'Fout in query',
	'Execute' => 'Uitvoeren',
	'Table' => 'Tabel',
	'Foreign keys' => 'Foreign keys',
	'Triggers' => 'Triggers',
	'View' => 'View',
	'Unable to select the table' => 'Onmogelijk tabel te selecteren',
	'Invalid CSRF token. Send the form again.' => 'Ongeldig CSRF token. Verstuur het formulier opnieuw.',
	'Comment' => 'Commentaar',
	'Default values has been set.' => 'Standaard waarde ingesteld.',
	'Default values' => 'Standaard waarden',
	'BOOL' => 'BOOL',
	'Show column comments' => 'Kolomcommentaar weergeven',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Geen opdrachten uit te voeren.',
	'Unable to upload a file.' => 'Onmogelijk bestand te uploaden.',
	'File upload' => 'Bestand uploaden',
	'File uploads are disabled.' => 'Bestanden uploaden is uitgeschakeld.',
	'Routine has been called, %d row(s) affected.' => array('Procedure uitgevoerd, %d rij geraakt.', 'Procedure uitgevoerd, %d rijen geraakt.'),
	'Call' => 'Uitvoeren',
	'No MySQL extension' => 'Geen MySQL extensie',
	'None of supported PHP extensions (%s) are available.' => 'Geen geldige PHP extensies beschikbaar (%s).',
	'Sessions must be enabled.' => 'Siessies moeten geactiveerd zijn.',
	'Session expired, please login again.' => 'Uw sessie is verlopen. Gelieve opnieuw in te loggen.',
	'Text length' => 'Tekst lengte',
	'Syntax highlighting' => 'Syntax highlighting',
	'Foreign key has been dropped.' => 'Foreign key verwijderd.',
	'Foreign key has been altered.' => 'Foreign key aangepast.',
	'Foreign key has been created.' => 'Foreign key aangemaakt.',
	'Foreign key' => 'Foreign key',
	'Target table' => 'Doeltabel',
	'Change' => 'Veranderen',
	'Source' => 'Bron',
	'Target' => 'Doel',
	'Add column' => 'Kolom toevoegen',
	'Alter' => 'Aanpassen',
	'Add foreign key' => 'Foreign key aanmaken',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Index type',
	'Column (length)' => 'Kolom (lengte)',
	'View has been dropped.' => 'View verwijderd.',
	'View has been altered.' => 'View aangepast.',
	'View has been created.' => 'View aangemaakt.',
	'Alter view' => 'View aanpassen',
	'Create view' => 'View aanmaken',
	'Name' => 'Naam',
	'Process list' => 'Proceslijst',
	'%d process(es) has been killed.' => array('%d proces gestopt.', '%d processen gestopt.'),
	'Kill' => 'Stoppen',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Parameternaam',
	'Database schema' => 'Database schema',
	'Create procedure' => 'Procedure aanmaken',
	'Create function' => 'Functie aanmaken',
	'Routine has been dropped.' => 'Procedure verwijderd.',
	'Routine has been altered.' => 'Procedure aangepast.',
	'Routine has been created.' => 'Procedure aangemaakt.',
	'Alter function' => 'Functie aanpassen',
	'Alter procedure' => 'Procedure aanpassen',
	'Return type' => 'Return type',
	'Add trigger' => 'Trigger aanmaken',
	'Trigger has been dropped.' => 'Trigger verwijderd.',
	'Trigger has been altered.' => 'Trigger aangepast.',
	'Trigger has been created.' => 'Trigger aangemaakt.',
	'Alter trigger' => 'Trigger aanpassen',
	'Create trigger' => 'Trigger aanmaken',
	'Time' => 'Time',
	'Event' => 'Event',
	'MySQL version: %s through PHP extension %s' => 'MySQL versie: %s met PHP extensie %s',
	'%d row(s)' => array('%d rij', '%d rijen'),
	'around %d row(s)' => array('ongeveer %d rij', 'ongeveer %d rijen'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => 'Verwijderen',
	'Are you sure?' => 'Weet u het zeker?',
	'Privileges' => 'Rechten',
	'Create user' => 'Gebruiker aanmaken',
	'User has been dropped.' => 'Gebruiker verwijderd.',
	'User has been altered.' => 'Gebruiker aangepast.',
	'User has been created.' => 'Gebruiker aangemaakt.',
	'Hashed' => 'Gehashed',
	'Column' => 'Kolom',
	'Routine' => 'Routine',
	'Grant' => 'Toekennen',
	'Revoke' => 'Intrekken',
	'Error during deleting' => 'Fout tijdens verwijderen',
	'%d item(s) have been deleted.' => array('%d item werd verwijderd.', '%d items warden verwijderd.'),
	'all' => 'alle',
	'Delete selected' => 'Geselecteerde verwijderen',
	'Logged as: %s' => 'Aangemeld als: %s',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'POST-data is te groot. Verklein de hoeveelheid data of verhoog de "post_max_size" configuratie.',
	'Move up' => 'Omhoog',
	'Move down' => 'Omlaag',
	'Export' => 'Exporteren',
	'skip' => 'overslaan',
	'Tables' => 'Tabellen',
	'Structure' => 'Structuur',
	'Data' => 'Data',
	'Output' => 'Uitvoer',
	'open' => 'openen',
	'save' => 'opslaan',
	'Format' => 'Formaat',
	'SQL' => 'SQL',
	'CSV' => 'CSV',
	'Functions' => 'Functies',
	'Aggregation' => 'Totalen',
	'Truncate result' => 'Afkappen',
	'Export selected' => 'Geselecteerde exporteren',
	'Export result' => 'Resultaten exporteren',
);

==> phpMinAdmin-1.9.1.zip: phpMinAdmin-1.9.1/lang/nl.inc.php <==
<?php
$translations = array(
	'Login' => 'Inloggen',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => 'Uitloggen geslaagd.',
	'Invalid credentials.' => 'Ongeldige logingegevens.',
	'Server' => 'Server',
	'Username' => 'Gebruikersnaam',
	'Password' => 'Wachtwoord',
	'Select database' => 'Database selecteren',
	'Invalid database.' => 'Ongeldige database.',
	'Create new database' => 'Nieuwe database',
	'Table has been dropped.' => 'Tabel verwijderd.',
	'Table has been altered.' => 'Tabel aangepast.',
	'Table has been created.' => 'Tabel aangemaakt.',
	'Alter table' => 'Tabel aanpassen',
	'Create table' => 'Tabel aanmaken',
	'Table name' => 'Tabelnaam',
	'engine' => 'engine',
	'collation' => 'collation',
	'Column name' => 'Kolomnaam',
	'Type' => 'Type',
	'Length' => 'Lengte',
	'NULL' => 'NULL',
	'Auto Increment' => 'Auto nummering',
	'Options' => 'Opties',
	'Save' => 'Opslaan',
	'Drop' => 'Verwijderen',
	'Database has been dropped.' => 'Database verwijderd.',
	'Database has been created.' => 'Database aangemaakt.',
	'Database has been renamed.' => 'Database hernoemd.',
	'Database has been altered.' => 'Database aangepast.',
	'Alter database' => 'Database aanpassen',
	'Create database' => 'Database aanmaken',
	'SQL command' => 'SQL opdracht',
	'Dump' => 'Exporteer',
	'Logout' => 'Uitloggen',
	'database' => 'database',
	'Use' => 'Gebruik',
	'No tables.' => 'Geen tabellen.',
	'select' => 'kies',
	'Create new table' => 'Nieuwe tabel',
	'Item has been deleted.' => 'Item verwijderd.',
	'Item has been updated.' => 'Item aangepast.',
	'Item has been inserted.' => 'Item toegevoegd.',
	'Edit' => 'Bewerk',
	'Insert' => 'Toevoegen',
	'Save and insert next' => 'Opslaan, daarna toevoegen',
	'Delete' => 'Verwijderen',
	'Database' => 'Database',
	'Routines' => 'Procedures',
	'Indexes has been altered.' => 'Index aangepast.',
	'Indexes' => 'Indexen',
	'Alter indexes' => 'Indexen aanpassen',
	'Add next' => 'Volgende toevoegen',
	'Language' => 'Taal',
	'Select' => 'Kies',
	'New item' => 'Nieuw item',
	'Search' => 'Zoeken',
	'Sort' => 'Sorteren',
	'DESC' => 'Aflopend',
	'Limit' => 'Beperk',
	'No rows.' => 'Geen rijen.',
	'Action' => 'Acties',
	'edit' => 'bewerk',
	'Page' => 'Pagina',
	'Query executed OK, %d row(s) affected.' => array('Query uitgevoerd, %d rij geraakt.', 'Query uitgevoerd, %d rijen geraakt.'),
	'Error in query' => 'Fout in query',
	'Execute' => 'Uitvoeren',
	'Table' => 'Tabel',
	'Foreign keys' => 'Foreign keys',
	'Triggers' => 'Triggers',
	'View' => 'View',
	'Unable to select the table' => 'Onmogelijk tabel te selecteren',
	'Invalid CSRF token. Send the form again.' => 'Ongeldig CSRF token. Verstuur het formulier opnieuw.',
	'Comment' => 'Commentaar',
	'Default values has been set.' => 'Standaard waarde ingesteld.',
	'Default values' => 'Standaard waarden',
	'BOOL' => 'BOOL',
	'Show column comments' => 'Kolomcommentaar weergeven',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Geen opdrachten uit te voeren.',
	'Unable to upload a file.' => 'Onmogelijk bestand te uploaden.',
	'File upload' => 'Bestand uploaden',
	'File uploads are disabled.' => 'Bestanden uploaden is uitgeschakeld.',
	'Routine has been called, %d row(s) affected.' => array('Procedure uitgevoerd, %d rij geraakt.', 'Procedure uitgevoerd, %d rijen geraakt.'),
	'Call' => 'Uitvoeren',
	'No MySQL extension' => 'Geen MySQL extensie',
	'None of supported PHP extensions (%s) are available.' => 'Geen geldige PHP extensies beschikbaar (%s).',
	'Sessions must be enabled.' => 'Siessies moeten geactiveerd zijn.',
	'Session expired, please login again.' => 'Uw sessie is verlopen. Gelieve opnieuw in te loggen.',
	'Text length' => 'Tekst lengte',
	'Syntax highlighting' => 'Syntax highlighting',
	'Foreign key has been dropped.' => 'Foreign key verwijderd.',
	'Foreign key has been altered.' => 'Foreign key aangepast.',
	'Foreign key has been created.' => 'Foreign key aangemaakt.',
	'Foreign key' => 'Foreign key',
	'Target table' => 'Doeltabel',
	'Change' => 'Veranderen',
	'Source' => 'Bron',
	'Target' => 'Doel',
	'Add column' => 'Kolom toevoegen',
	'Alter' => 'Aanpassen',
	'Add foreign key' => 'Foreign key aanmaken',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Index type',
	'Column (length)' => 'Kolom (lengte)',
	'View has been dropped.' => 'View verwijderd.',
	'View has been altered.' => 'View aangepast.',
	'View has been created.' => 'View aangemaakt.',
	'Alter view' => 'View aanpassen',
	'Create view' => 'View aanmaken',
	'Name' => 'Naam',
	'Process list' => 'Proceslijst',
	'%d process(es) has been killed.' => array('%d proces gestopt.', '%d processen gestopt.'),
	'Kill' => 'Stoppen',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Parameternaam',
	'Database schema' => 'Database schema',
	'Create procedure' => 'Procedure aanmaken',
	'Create function' => 'Functie aanmaken',
	'Routine has been dropped.' => 'Procedure verwijderd.',
	'Routine has been altered.' => 'Procedure aangepast.',
	'Routine has been created.' => 'Procedure aangemaakt.',
	'Alter function' => 'Functie aanpassen',
	'Alter procedure' => 'Procedure aanpassen',
	'Return type' => 'Return type',
	'Add trigger' => 'Trigger aanmaken',
	'Trigger has been dropped.' => 'Trigger verwijderd.',
	'Trigger has been altered.' => 'Trigger aangepast.',
	'Trigger has been created.' => 'Trigger aangemaakt.',
	'Alter trigger' => 'Trigger aanpassen',
	'Create trigger' => 'Trigger aanmaken',
	'Time' => 'Time',
	'Event' => 'Event',
	'MySQL version: %s through PHP extension %s' => 'MySQL versie: %s met PHP extensie %s',
	'%d row(s)' => array('%d rij', '%d rijen'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => 'Verwijderen',
	'Are you sure?' => 'Weet u het zeker?',
	'Privileges' => 'Rechten',
	'Create user' => 'Gebruiker aanmaken',
	'User has been dropped.' => 'Gebruiker verwijderd.',
	'User has been altered.' => 'Gebruiker aangepast.',
	'User has been created.' => 'Gebruiker aangemaakt.',
	'Hashed' => 'Gehashed',
	'Column' => 'Kolom',
	'Routine' => 'Routine',
	'Grant' => 'Toekennen',
	'Revoke' => 'Intrekken',
	'Logged as: %s' => 'Aangemeld als: %s',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'POST-data is te groot. Verklein de hoeveelheid data of verhoog de "post_max_size" configuratie.',
	'Move up' => 'Omhoog',
	'Move down' => 'Omlaag',
	'Export' => 'Exporteren',
	'skip' => 'overslaan',
	'Tables' => 'Tabellen',
	'Structure' => 'Structuur',
	'Data' => 'Data',
	'Output' => 'Uitvoer',
	'open' => 'openen',
	'save' => 'opslaan',
	'Format' => 'Formaat',
	'SQL' => 'SQL',
	'CSV' => 'CSV',
	'Functions' => 'Functies',
	'Aggregation' => 'Totalen',
	'Event has been dropped.' => 'Event werd verwijderd.',
	'Event has been altered.' => 'Event werd aangepast.',
	'Event has been created.' => 'Event werd aangemaakt.',
	'Alter event' => 'Event aanpassen',
	'Create event' => 'Event aanmaken',
	'Start' => 'Start',
	'End' => 'Stop',
	'Every' => 'Iedere',
	'Status' => 'Status',
	'On completion preserve' => 'Bewaren na voltooiing',
	'Events' => 'Events',
	'Schedule' => 'Schedule',
	'At given time' => 'Op aangegeven tijd',
	'Save and continue edit' => 'Opslaan en verder bewerken',
	'original' => 'origineel',
	'Tables have been truncated.' => 'Tabellen werden geleegd.',
	'Tables have been moved.' => 'Tabellen werden verplaatst.',
	'Tables have been dropped.' => 'Tabellen werden verwijderd.',
	'Tables and views' => 'Tabellen en views',
	'Engine' => 'Engine',
	'Collation' => 'Collatie',
	'Data Length' => 'Data lengte',
	'Index Length' => 'Index lengte',
	'Data Free' => 'Data Vrij',
	'Rows' => 'Rijen',
	',' => '.',
	'Analyze' => 'Analyseer',
	'Optimize' => 'Optimaliseer',
	'Check' => 'Controleer',
	'Repair' => 'Herstel',
	'Truncate' => 'Legen',
	'Move to other database' => 'Verplaats naar andere database',
	'Move' => 'Verplaats',
	'%d item(s) have been affected.' => array('%d item aangepast.', '%d items aangepast.'),
	'whole result' => 'volledig resultaat',
	'clone' => 'dupliceer',
	'Clone' => 'Dupliceer',
);
